# 2022-04-25 - Unbutton Aave Linear Pool

> ⚠️ **DEPRECATED: do not use** ⚠️
>

Deployment of the `UnbuttonAaveLinearPoolFactory`, for Aave Linear Pools where both the main and wrapped tokens are UnbuttonTokens employing the IButtonWrapper interface to abstract rebasing functionality.

## Useful Files

- [Ethereum mainnet addresses](./output/mainnet.json)
- [Polygon mainnet addresses](./output/polygon.json)
- [Arbitrum mainnet addresses](./output/arbitrum.json)
- [Optimism mainnet addresses](./output/optimism.json)
- [Gnosis mainnet addresses](./output/gnosis.json)
- [Goerli testnet addresses](./output/goerli.json)
- [`UnbuttonAaveLinearPoolFactory` artifact](./artifact/UnbuttonAaveLinearPoolFactory.json)
